FutureSoket class

Constructors

FutureSoket()
FutureSoket.fromSoket(Socket? _socket)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(dynamic host, int port, [Duration? timeout]) Future<void>
disconnect() Future<void>
isConnected() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int len, [Duration? timeout]) Future<Uint8List>
toString() String
A string representation of this object.
inherited
write(Uint8List buf) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited